#[repr(transparent)]pub struct Ch0sema(pub u32);Expand description
DCP channel 0 semaphore register
Tuple Fields
0: u32Implementations
Sourceimpl Ch0sema
impl Ch0sema
Sourcepub const fn increment(&self) -> u8
pub const fn increment(&self) -> u8
The value written to this field is added to the semaphore count in an atomic way such that the simultaneous software adds and DCP hardware substracts happening on the same clock are protected
Sourcepub const fn set_increment(&mut self, val: u8)
pub const fn set_increment(&mut self, val: u8)
The value written to this field is added to the semaphore count in an atomic way such that the simultaneous software adds and DCP hardware substracts happening on the same clock are protected