nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Ch3optsSet

Struct Ch3optsSet 

#[repr(transparent)]
pub struct Ch3optsSet(pub u32);
DCP channel 3 options register

Tuple Fields

0: u32

Implementations

Source

impl Ch3optsSet

pub const fn recovery_timer(&self) -> u16

This field indicates the recovery time for the channel

pub const fn set_recovery_timer(&mut self, val: u16)

This field indicates the recovery time for the channel