nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

ChannelctrlClr

Struct ChannelctrlClr 

#[repr(transparent)]
pub struct ChannelctrlClr(pub u32);
DCP channel control register

Tuple Fields

0: u32

Implementations

Source

impl ChannelctrlClr

pub const fn enable_channel(&self) -> ChannelctrlClrEnableChannel

Setting a bit in this field enables the DMA channel associated with it

pub const fn set_enable_channel(&mut self, val: ChannelctrlClrEnableChannel)

Setting a bit in this field enables the DMA channel associated with it

pub const fn high_priority_channel(&self) -> ChannelctrlClrHighPriorityChannel

Setting a bit in this field causes the corresponding channel to have high-priority arbitration

pub const fn set_high_priority_channel( &mut self, val: ChannelctrlClrHighPriorityChannel, )

Setting a bit in this field causes the corresponding channel to have high-priority arbitration

pub const fn ch0_irq_merged(&self) -> bool

Indicates that the interrupt for channel 0 must be merged with the other interrupts on the shared dcp_irq interrupt

pub const fn set_ch0_irq_merged(&mut self, val: bool)

Indicates that the interrupt for channel 0 must be merged with the other interrupts on the shared dcp_irq interrupt